References not provided inline in this manual
---------------------------------------------

.. [Cal15] Sergio Callegari, Federico Bizzarri "Optimal Design of the Noise
   Transfer Function of ΔΣ Modulators: IIR strategies, FIR strategies,
   FIR strategies with Preassigned Poles," Signal Processing, Elsevier,
   2015. DOI:  10.1016/j.sigpro.2015.02.001.

.. [Dun97] C. Dunn and M. Sandler, “Psychoacoustically optimal
   sigma-delta modulation,” in Audio Engineering Society Convention 99, 1995.

.. [Nag12] M. Nagahara and Y. Yamamoto, “Frequency Domain Min-Max
   Optimization of Noise-Shaping Delta-Sigma Modulators,” IEEE
   Transactions on Signal Processing, vol. 60, no. 6,
   pp. 2828–2839, Jun. 2012.
